
## CATO-CLI - mutation.policy.antiMalwareFileHash.discardPolicyRevision:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.discardPolicyRevision) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.discardPolicyRevision:

```bash
catocli mutation policy antiMalwareFileHash discardPolicyRevision -h

catocli mutation policy antiMalwareFileHash discardPolicyRevision <json>

catocli mutation policy antiMalwareFileHash discardPolicyRevision "$(cat < mutation.policy.antiMalwareFileHash.discardPolicyRevision.json)"

catocli mutation policy antiMalwareFileHash discardPolicyRevision '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"policyDiscardRevisionInput":{"id":"id"}}'

catocli mutation policy antiMalwareFileHash discardPolicyRevision '{
    "antiMalwareFileHashPolicyMutationInput": {
        "policyMutationRevisionInput": {
            "id": "id"
        }
    },
    "policyDiscardRevisionInput": {
        "id": "id"
    }
}'
```

#### Operation Arguments for mutation.policy.antiMalwareFileHash.discardPolicyRevision ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`policyDiscardRevisionInput` [PolicyDiscardRevisionInput] - (required) N/A    
